@@ -22,7 +22,7 @@ def curve_fit_ode(model,
 
     Args:
         model (callable(y,t,...)): The function computes the derivative of y at t.
-        var0 (array): Initial condition on var.
+        var0 (callable or array): Initial condition of var.
         t (array): A sequence of time points for which to solve for y. The initial
                     value point should be the first element of this sequence.
         xdata (array): The independent variable where the data is measured.
@@ -80,11 +80,6 @@ def curve_fit_ode(model,
     
     # set the default bounds
     if (bounds == None) & (guess0 != None):
-        # bounds = (
-        #     [-np.inf] * (len(set(guess0))),
-        #     [np.inf] * (len(set(guess0))),
-        # )
-
         bounds = np.empty([2, len(guess0)])
         for i in range(len(guess0)):
             if guess0[i] > 0:
@@ -136,7 +131,7 @@ def curve_fit_ode(model,
         except:
                 return results[col_index][~np.isnan(ydata)]
         
-    avg, std = sp.curve_fit(func, xdata, ydata[~np.isnan(ydata)], p0=guess0, bounds=bounds)
+    avg, std = sp.optimize.curve_fit(func, xdata, ydata[~np.isnan(ydata)], p0=guess0, bounds=bounds)
     try:
          df = sol_ode(model, var0(param_var0), t, param)
     except:
