@@ -5,14 +5,6 @@ import scipy as sp
 import odeintw as ow
 import tqdm as tq
 
-from scipy.integrate import odeint, cumulative_trapezoid, solve_bvp, solve_ivp
-from scipy.interpolate import InterpolatedUnivariateSpline as fitline
-from scipy.fft import fft
-from scipy.optimize import curve_fit, fsolve
-from scipy.optimize.nonlin import nonlin_solve
-from scipy.signal import find_peaks
-
-from decimal import *
 
 def sol_ode(model, var0, t, param):
 
@@ -27,23 +19,19 @@ def sol_ode(model, var0, t, param):
         param (array): Parameters of the model.
 
     Returns:
-        df (dataframe): Dataframe containing the value of var for each desired time in
-                        tspan, with the initial value var0 in the first row and time
-                        as index.
+        ar (array): Array containing the value of var for each desired time in t, with the initial value var0 in the first row
     """
-    try:
-         if (isinstance(param,list)) & (len(param) == 1):
-             param = param[0]
-         else:
-             pass
-    except:
-         pass
-    
-    try:
-        if isinstance(var0,list) & len(var0) == 1:
+    if isinstance(param,list):
+        if (len(param) == 1):
+            param = param[0]
+        else: pass
+    else: pass
+
+    if isinstance(var0,list):
+        if (len(var0) == 1) :
             var0 = var0[0]
-    except:
-        pass
+        else: pass
+    else: pass
     
     results = ow.odeintw(model, y0=var0, t=t, args=(param,))
     
@@ -51,9 +39,9 @@ def sol_ode(model, var0, t, param):
     
     if isinstance(out, tuple):
         m = int(np.shape(var0)[0])
-        df = list(range(m))
+        ar = list(range(m))
         for i in range(m):
-            df[i] = results[:,i]
+            ar[i] = results[:,i]
     else:
-        df = results
-    return df
\ No newline at end of file
+        ar = results
+    return ar
\ No newline at end of file
